==> openvdb-12.1.1-2-x86_64.pkg.tar.zst: usr/share/doc/OpenVDB/html/Mat4_8h.js <==
var Mat4_8h =
[
    [ "Mat4< T >", "classopenvdb_1_1v12__1_1_1math_1_1Mat4.html", "classopenvdb_1_1v12__1_1_1math_1_1Mat4" ],
    [ "openvdb::v12_1::math::Mat4d", "namespaceopenvdb_1_1v12__1_1_1math.html#abaf7f913bf1752b9157259ffa32704ca", null ],
    [ "openvdb::v12_1::math::Mat4f", "namespaceopenvdb_1_1v12__1_1_1math.html#a3fdbbddbd6905aded64c2986f68920e7", null ],
    [ "openvdb::v12_1::math::Mat4s", "namespaceopenvdb_1_1v12__1_1_1math.html#a1e0cebbadc8b83a7e703d21de5539beb", null ],
    [ "openvdb::v12_1::math::Abs", "namespaceopenvdb_1_1v12__1_1_1math.html#a12b142c23f4c2bba04e9aeff6d87e2e8", null ],
    [ "openvdb::v12_1::math::cwiseAdd", "namespaceopenvdb_1_1v12__1_1_1math.html#ac683f5033ebbe9458282e594c8e6263a", null ],
    [ "openvdb::v12_1::math::cwiseGreaterThan", "namespaceopenvdb_1_1v12__1_1_1math.html#ab96e0cbee974c0c13e155203d63acc3e", null ],
    [ "openvdb::v12_1::math::cwiseLessThan", "namespaceopenvdb_1_1v12__1_1_1math.html#a767a00343bfc28336a8e9f2c363d0532", null ],
    [ "openvdb::v12_1::math::hasTranslation", "namespaceopenvdb_1_1v12__1_1_1math.html#a0af027c174ba68c31db6eaaa28bce22e", null ],
    [ "openvdb::v12_1::math::isAffine", "namespaceopenvdb_1_1v12__1_1_1math.html#a9f690c02c428a072792d1574be0ab9b5", null ],
    [ "openvdb::v12_1::math::transformNormal", "namespaceopenvdb_1_1v12__1_1_1math.html#a08abfdd350e785e1b5fe4b0b37ad21b2", null ],
    [ "openvdb::v12_1::zeroVal< math::Mat4d >", "namespaceopenvdb_1_1v12__1.html#a8eb6e8114dc9fe2d9e0822f90feaca24", null ],
    [ "openvdb::v12_1::zeroVal< math::Mat4s >", "namespaceopenvdb_1_1v12__1.html#a020579e02abb5c74bdcb317e7a53e591", null ]
];

==> openvdb-12.1.1-3-x86_64.pkg.tar.zst: usr/share/doc/OpenVDB/html/Mat4_8h.js <==
var Mat4_8h =
[
    [ "Mat4&lt; T &gt;", "classopenvdb_1_1v12__1_1_1math_1_1Mat4.html", "classopenvdb_1_1v12__1_1_1math_1_1Mat4" ],
    [ "openvdb::v12_1::math::Mat4d", "namespaceopenvdb_1_1v12__1_1_1math.html#abaf7f913bf1752b9157259ffa32704ca", null ],
    [ "openvdb::v12_1::math::Mat4f", "namespaceopenvdb_1_1v12__1_1_1math.html#a3fdbbddbd6905aded64c2986f68920e7", null ],
    [ "openvdb::v12_1::math::Mat4s", "namespaceopenvdb_1_1v12__1_1_1math.html#a1e0cebbadc8b83a7e703d21de5539beb", null ],
    [ "openvdb::v12_1::math::Abs", "namespaceopenvdb_1_1v12__1_1_1math.html#a12b142c23f4c2bba04e9aeff6d87e2e8", null ],
    [ "openvdb::v12_1::math::cwiseAdd", "namespaceopenvdb_1_1v12__1_1_1math.html#ac683f5033ebbe9458282e594c8e6263a", null ],
    [ "openvdb::v12_1::math::cwiseGreaterThan", "namespaceopenvdb_1_1v12__1_1_1math.html#ab96e0cbee974c0c13e155203d63acc3e", null ],
    [ "openvdb::v12_1::math::cwiseLessThan", "namespaceopenvdb_1_1v12__1_1_1math.html#a767a00343bfc28336a8e9f2c363d0532", null ],
    [ "openvdb::v12_1::math::hasTranslation", "namespaceopenvdb_1_1v12__1_1_1math.html#a0af027c174ba68c31db6eaaa28bce22e", null ],
    [ "openvdb::v12_1::math::isAffine", "namespaceopenvdb_1_1v12__1_1_1math.html#a9f690c02c428a072792d1574be0ab9b5", null ],
    [ "openvdb::v12_1::math::transformNormal", "namespaceopenvdb_1_1v12__1_1_1math.html#a08abfdd350e785e1b5fe4b0b37ad21b2", null ],
    [ "openvdb::v12_1::zeroVal< math::Mat4d >", "namespaceopenvdb_1_1v12__1.html#a8eb6e8114dc9fe2d9e0822f90feaca24", null ],
    [ "openvdb::v12_1::zeroVal< math::Mat4s >", "namespaceopenvdb_1_1v12__1.html#a020579e02abb5c74bdcb317e7a53e591", null ]
];
